| check_coverage | R Documentation |
Queries The Taxonomicon for a taxon name and returns a logical indicating whether the taxon was found. Useful for pre-screening a list of names before running distance computations.
check_coverage(taxa, verbose = FALSE)
taxa |
A character vector of one or more taxon names. |
verbose |
Logical. If |
A named logical vector. TRUE indicates the taxon was found,
FALSE indicates it was not.
check_coverage(c("Tyrannosaurus", "Velociraptor", "Fakeosaurus"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.