| filter_clade | R Documentation |
Given a vector of taxon names and a clade name, returns only those taxa whose lineage includes the specified clade.
filter_clade(taxa, clade, verbose = FALSE)
taxa |
A character vector of taxon names. |
clade |
A character string giving the clade to filter by. |
verbose |
Logical. If |
A character vector of taxa that are members of the specified clade.
taxa <- c("Tyrannosaurus", "Triceratops", "Velociraptor",
"Brachiosaurus", "Homo")
filter_clade(taxa, "Theropoda")
filter_clade(taxa, "Dinosauria")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.