| mrca | R Documentation |
Retrieves the lineages of two taxa and returns the name of their most recent common ancestor (MRCA) — the deepest node shared by both lineages.
mrca(taxon_a, taxon_b, verbose = FALSE)
taxon_a |
A character string giving the first taxon name. |
taxon_b |
A character string giving the second taxon name. |
verbose |
Logical. If |
A character string giving the name of the MRCA, or NULL if
either taxon cannot be found or no common ancestor exists.
mrca("Tyrannosaurus", "Velociraptor") # "Tyrannoraptora"
mrca("Tyrannosaurus", "Triceratops") # "Dinosauria"
mrca("Tyrannosaurus", "Homo") # "Amniota"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.