summary.taxodist_ord: Summary method for taxodist_ord objects

View source: R/utils.R

summary.taxodist_ordR Documentation

Summary method for taxodist_ord objects

Description

Prints a summary of the PCoA ordination, including the goodness-of-fit and the proportion of variance explained by each principal coordinate.

Usage

## S3 method for class 'taxodist_ord'
summary(object, ...)

Arguments

object

A taxodist_ord object from taxo_ordinate.

...

Additional arguments (ignored).

Value

Invisibly returns a data frame containing the eigenvalues and variance explained by each dimension.


taxodist documentation built on May 6, 2026, 1:06 a.m.