| clear_cache | R Documentation |
Clears all cached lineages stored in the current R session. Useful when you suspect cached data is stale or want to force fresh retrieval.
clear_cache()
Invisibly returns NULL.
clear_cache()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.