| is_member | R Documentation |
Returns TRUE if taxon is a member of clade — i.e., if the clade name
appears in the taxon's lineage.
is_member(taxon, clade, verbose = FALSE)
taxon |
A character string giving the taxon name to test. |
clade |
A character string giving the clade name to test membership in. |
verbose |
Logical. If |
A logical value, or NULL if the taxon cannot be found.
is_member("Tyrannosaurus", "Theropoda") # TRUE
is_member("Triceratops", "Theropoda") # FALSE
is_member("Homo", "Amniota") # TRUE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.