| shared_clades | R Documentation |
Returns the vector of clade names forming the shared trunk of two taxa's lineages, from root down to (and including) their MRCA.
shared_clades(taxon_a, taxon_b, verbose = FALSE)
taxon_a |
A character string giving the first taxon name. |
taxon_b |
A character string giving the second taxon name. |
verbose |
Logical. If |
A character vector of shared clade names ordered from root to MRCA,
or NULL if either taxon cannot be found.
shared_clades("Tyrannosaurus", "Velociraptor")
shared_clades("Tyrannosaurus", "Homo")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.