| summary.taxodist_ord | R Documentation |
Prints a summary of the PCoA ordination, including the goodness-of-fit and the proportion of variance explained by each principal coordinate.
## S3 method for class 'taxodist_ord'
summary(object, ...)
object |
A |
... |
Additional arguments (ignored). |
Invisibly returns a data frame containing the eigenvalues and variance explained by each dimension.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.